@@ -16,14 +16,14 @@ class AndroidDriver(object):
         :return:
         '''
         try:
-            log_info('adb: {}'.format(cmd))
+            log_info(' adb: {}'.format(cmd))
             if cmd.startswith('shell'):
-                cmd = ["adb", "-s", Var.udid, "shell", "{}".format(cmd.lstrip('shell').strip())]
+                cmd = ["adb", "-s", Var.desired_caps.udid, "shell", "{}".format(cmd.lstrip('shell').strip())]
                 pipe = subprocess.Popen(cmd, stdin=subprocess.PIPE,
                                         stdout=subprocess.PIPE)
                 out = pipe.communicate()
             else:
-                cmd = ["adb", "-s", Var.udid, "{}".format(cmd)]
+                cmd = ["adb", "-s", Var.desired_caps.udid, "{}".format(cmd)]
                 os.system(' '.join(cmd))
         except:
             raise Exception(traceback.format_exc())
@@ -171,7 +171,7 @@ class AndroidDriver(object):
         try:
             width = Var.instance.get_window_size()['width']
             height = Var.instance.get_window_size()['height']
-            AndroidDriver.swipe(width / 2, height * 3 / 4, width / 2, height / 4, duration)
+            AndroidDriver.swipe(width / 2, height * 0.65, width / 2, height / 4, duration)
         except Exception as e:
             raise e
 
@@ -309,11 +309,7 @@ class AndroidDriver(object):
         :return:
         '''
         try:
-            Var.instance.implicitly_wait(int(timeout)/2)
-            elements = Var.instance.find_elements_by_accessibility_id(name)
-            if not elements:
-                elements = Var.instance.find_elements_by_android_uiautomator('new UiSelector().text("{}")'.format(name))
-            Var.instance.implicitly_wait(timeout)
+            elements = Var.instance.find_elements_by_android_uiautomator('new UiSelector().text("{}")'.format(name))
             return elements
         except Exception as e:
             raise e
@@ -486,7 +482,7 @@ class iOSDriver(object):
         try:
             width = Var.instance.get_window_size()['width']
             height = Var.instance.get_window_size()['height']
-            iOSDriver.swipe(width / 2, height * 3 / 4, width / 2, height / 4, duration)
+            iOSDriver.swipe(width / 2, height * 0.65, width / 2, height / 4, duration)
         except Exception as e:
             raise e
 
@@ -530,7 +526,7 @@ class iOSDriver(object):
             raise e
 
     @staticmethod
-    def swipe(from_x, from_y, to_x, to_y, duration=3):
+    def swipe(from_x, from_y, to_x, to_y, duration=2):
         '''
         :param from_x:
         :param from_y:
@@ -550,7 +546,7 @@ class iOSDriver(object):
                 to_x = to_x * width
             if to_y <= 1.0:
                 to_y = to_y * height
-            Var.instance.swipe(int(from_x), int(from_y), int(to_x), int(to_y), duration * 100)
+            Var.instance.swipe(int(from_x), int(from_y), int(to_x), int(to_y), int(duration * 100))
         except Exception as e:
             raise e
 
