@@ -15,14 +15,14 @@ class AndroidDriver(object):
         :return:
         '''
         try:
-            log_info('adb {}'.format(cmd))
+            log_info(' adb {}'.format(cmd))
             if cmd.startswith('shell'):
-                cmd = ["adb", "-s", Var.udid, "shell", "{}".format(cmd.lstrip('shell').strip())]
+                cmd = ["adb", "-s", Var.desired_caps.udid, "shell", "{}".format(cmd.lstrip('shell').strip())]
                 pipe = subprocess.Popen(cmd, stdin=subprocess.PIPE,
                                         stdout=subprocess.PIPE)
                 out = pipe.communicate()
             else:
-                cmd = ["adb", "-s", Var.udid, "{}".format(cmd)]
+                cmd = ["adb", "-s", Var.desired_caps.udid, "{}".format(cmd)]
                 os.system(' '.join(cmd))
         except:
             raise Exception(traceback.format_exc())
@@ -60,7 +60,7 @@ class AndroidDriver(object):
         '''
         try:
             if not package_info:
-                AndroidDriver.adb_shell('shell am start -W {}/{}'.format(Var.package, Var.activity))
+                AndroidDriver.adb_shell('shell am start -W {}/{}'.format(Var.desired_caps.package, Var.desired_caps.activity))
             else:
                 AndroidDriver.adb_shell('shell am start -W {}'.format(package_info))
 
@@ -76,7 +76,7 @@ class AndroidDriver(object):
         '''
         try:
             if not package_info:
-                AndroidDriver.adb_shell('shell am force-stop {}'.format(Var.package))
+                AndroidDriver.adb_shell('shell am force-stop {}'.format(Var.desired_caps.package))
             else:
                 AndroidDriver.adb_shell('shell am force-stop {}'.format(package_info))
         except Exception as e:
@@ -158,7 +158,7 @@ class AndroidDriver(object):
         try:
             width = Var.instance.get_window_size()['width']
             height = Var.instance.get_window_size()['height']
-            AndroidDriver.swipe(width / 2, height * 3 / 4, width / 2, height / 4, duration)
+            AndroidDriver.swipe(width / 2, height * 0.65, width / 2, height / 4, duration)
         except Exception as e:
             raise e
 
@@ -336,7 +336,7 @@ class iOSDriver(object):
         :return:
         '''
         try:
-            os.system('ideviceinstaller -u {} -i {}'.format(Var.udid, app_path))
+            os.system('ideviceinstaller -u {} -i {}'.format(Var.desired_caps.udid, app_path))
         except Exception as e:
             raise e
 
@@ -348,7 +348,7 @@ class iOSDriver(object):
         :return:
         '''
         try:
-            os.system('ideviceinstaller -u {} -U {}'.format(Var.udid, package_info))
+            os.system('ideviceinstaller -u {} -U {}'.format(Var.desired_caps.udid, package_info))
         except Exception as e:
             raise e
 
@@ -444,7 +444,7 @@ class iOSDriver(object):
             raise e
 
     @staticmethod
-    def swipe_up(duration=2):
+    def swipe_up(duration=0):
         '''
         :param duration:
         :return:
@@ -452,7 +452,7 @@ class iOSDriver(object):
         try:
             width = Var.instance.get_window_size()['width']
             height = Var.instance.get_window_size()['height']
-            iOSDriver.swipe(width / 2, height * 3 / 4, width / 2, height / 4, duration)
+            iOSDriver.swipe(width / 2, height * 0.65, width / 2, height / 4, duration)
         except Exception as e:
             raise e
 
@@ -516,7 +516,7 @@ class iOSDriver(object):
                 to_x = to_x * width
             if to_y <= 1.0:
                 to_y = to_y * height
-            Var.instance.swipe(from_x, from_y, to_x, to_y, duration * 100)
+            Var.instance.touch('drag', { 'fromX': from_x, 'fromY': from_y, 'toX': to_x, 'toY': to_y, 'duration': duration})
         except Exception as e:
             raise e
 
