@@ -3,7 +3,8 @@
 from fasttest.utils.yaml_utils import analytical_file
 from fasttest.utils.devices_utils import DevicesUtils
 from fasttest.utils.opcv_utils import OpencvUtils
-from fasttest.utils.server_utils import ServerUtils
+from fasttest.utils.server_utils_app import ServerUtilsApp
+from fasttest.utils.server_utils_web import ServerUtilsWeb
 from fasttest.utils.testcast_utils import TestCaseUtils
 
-__all__ = ['analytical_file', 'DevicesUtils', 'OpencvUtils', 'ServerUtils', 'TestCaseUtils']
\ No newline at end of file
+__all__ = ['analytical_file', 'DevicesUtils', 'OpencvUtils', 'ServerUtilsApp', 'ServerUtilsWeb', 'TestCaseUtils']
\ No newline at end of file
