@@ -1,35 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import os
-import cv2
-from fasttest.common import Var
-
+try:
+    import cv2
+except:
+    pass
 
 class OpencvUtils(object):
 
-    def __init__(self,action, matchimage):
+    def __init__(self,baseimage, matchimage, height):
 
-        self.action = action
-        self.baseimage = None
+        self.baseimage = baseimage
         self.matchimage = matchimage
+        self.height = height
         self.iszoom = False
 
-    def save_screenshot(self):
-        """
-        截图
-        :return:
-        """
-        try:
-            ocrimg = os.path.join(Var.ROOT, 'OcrImg')
-            if not os.path.exists(ocrimg):
-                os.makedirs(ocrimg)
-            imgname = self.matchimage.split(os.sep)[-1]
-            file_path = os.path.join(ocrimg, '{}_{}'.format(self.action, imgname))
-            Var.instance.save_screenshot(file_path)
-            self.baseimage = file_path
-        except Exception as e:
-            raise e
-
     def extract_minutiae(self):
         """
         提取特征点
@@ -40,7 +25,7 @@ class OpencvUtils(object):
             # self.baseimage = cv2.resize(self.baseimage, dsize=(int(self.baseimage.shape[1] / 2), int(self.baseimage.shape[0] / 2)))
             self.matchimage = cv2.imread(self.matchimage)
 
-            view_height = Var.instance.get_window_size()['height']
+            view_height = self.height
             image_height = self.baseimage.shape[0]
             if view_height * 2 == image_height:
                 self.iszoom = True
@@ -72,22 +57,24 @@ class OpencvUtils(object):
                 maxMatch = matchePoints[i].distance
         if minMatch > 0.2:
             return None
-        # #获取排雷在前边的几个最优匹配结果
+        # #获取排列在前边的几个最优匹配结果
         DMatch = None
         MatchePoints = []
         for i in range(len(matchePoints)):
             if matchePoints[i].distance == minMatch:
+                try:
+                    keypoint = keypoints1[matchePoints[i].queryIdx]
+                    x, y = keypoint.pt
+                    if self.iszoom:
+                        x = x / 2.0
+                        y = y / 2.0
+                    keypoints1 = [keypoint]
 
-                keypoint = keypoints1[matchePoints[i].queryIdx]
-                x, y = keypoint.pt
-                if self.iszoom:
-                    x = x / 2.0
-                    y = y / 2.0
-                keypoints1 = [keypoint]
-
-                dmatch = matchePoints[i]
-                dmatch.queryIdx = 0
-                MatchePoints.append(dmatch)
+                    dmatch = matchePoints[i]
+                    dmatch.queryIdx = 0
+                    MatchePoints.append(dmatch)
+                except:
+                    continue
 
         # 绘制最优匹配点
         outImg = None
